@@ -30,7 +30,7 @@ class Supervisor(Process):
         if not pid:
             # todo: 增加 config_file 不存在的判断
             self.host.ssh(f'supervisord -c {self.config_file}', sudo=True, warn=False)
-        self.host.ssh('chmod 770 /var/run/supervisor.sock', sudo=True, warn=False)
+            self.host.ssh('chmod 770 /var/run/supervisor.sock', sudo=True)
 
     def uninstall(self):
         """ 卸载supervisor
